--- ./FAQ.orig	2014-06-02 11:02:44.000000000 +0600
+++ ./FAQ	2014-06-02 13:24:56.000000000 +0600
@@ -53,7 +53,7 @@
 
 This command line will add lines to:
 {{{
-/etc/yum/pluginconf.d/versionlock.list
+/opt/freeware/etc/yum/pluginconf.d/versionlock.list
 }}}
 
 The config file uses the following format:
@@ -79,9 +79,9 @@
 [http://yum.baseurl.org/gitweb]
 The files you need will be found in the ''yum-utils/plugins/versionlock''
 part of the git tree.
-Copy versionlock.py   to ''/usr/lib/yum-plugins/versionlock.py''
-Copy versionlock.conf to ''/etc/yum/pluginconf.d/versionlock.conf''
-Create ''/etc/yum/pluginconf.d/versionlock.list''
+Copy versionlock.py   to ''/opt/freeware/lib/yum-plugins/versionlock.py''
+Copy versionlock.conf to ''/opt/freeware/etc/yum/pluginconf.d/versionlock.conf''
+Create ''/opt/freeware/etc/yum/pluginconf.d/versionlock.list''
 All files should be ''root.root'' with ''644'' permissions.
 
 
@@ -286,7 +286,7 @@
 
 ==== Q. 17: Why does yum always seem to update the metadata on EVERY run? ====
 '''A.''' It doesn't. It updates to check the metadata any time the cache timeout
- has been hit. The default can be set in your /etc/yum.conf
+ has been hit. The default can be set in your /opt/freeware/etc/yum.conf
 file and per repository config. see the yum man page and look for the metadata_e
 xpire value for how to set it to a different value.
 ----
--- ./README.orig	2014-06-02 11:02:44.000000000 +0600
+++ ./README	2014-06-02 14:21:53.000000000 +0600
@@ -3,7 +3,7 @@
 -------------------------------------
 
 Included programs:
-/usr/bin/yum		Main program
+/opt/freeware/bin/yum		Main program
 
 Basic usage description follows:
 
--- ./callback.py.orig	2014-06-02 11:02:44.000000000 +0600
+++ ./callback.py	2014-06-02 15:05:52.000000000 +0600
@@ -1,4 +1,4 @@
-#!/usr/bin/python -t
+#!/opt/freeware/bin/python2 -t
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
--- ./cli.py.orig	2014-06-02 11:02:44.000000000 +0600
+++ ./cli.py	2014-06-02 15:08:07.000000000 +0600
@@ -1,4 +1,4 @@
-#!/usr/bin/python -t
+#!/opt/freeware/bin/python2 -t
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
@@ -1646,10 +1646,10 @@
         if opts.installroot:
             if os.access(opts.installroot+'/'+opts.conffile, os.R_OK):
                 opts.conffile = opts.installroot+'/'+opts.conffile
-            elif opts.conffile == '/etc/yum/yum.conf':
+            elif opts.conffile == '/opt/freeware/etc/yum/yum.conf':
                 # check if /installroot/etc/yum.conf exists.
-                if os.access(opts.installroot+'/etc/yum.conf', os.R_OK):
-                    opts.conffile = opts.installroot+'/etc/yum.conf'         
+                if os.access(opts.installroot+'/opt/freeware/etc/yum.conf', os.R_OK):
+                    opts.conffile = opts.installroot+'/opt/freeware/etc/yum.conf'         
             root=opts.installroot
         else:
             root = '/'
@@ -1690,7 +1690,7 @@
                 action="store_true",
                 help=_("run entirely from system cache, don't update cache"))
         group.add_option("-c", "--config", dest="conffile",
-                default='/etc/yum/yum.conf',
+                default='/opt/freeware/etc/yum/yum.conf',
                 help=_("config file location"), metavar='[config file]')
         group.add_option("-R", "--randomwait", dest="sleeptime", type='int',
                 default=None,
--- ./output.py.orig	2014-06-02 11:02:44.000000000 +0600
+++ ./output.py	2014-06-02 15:36:38.000000000 +0600
@@ -1,4 +1,4 @@
-#!/usr/bin/python -t
+#!/opt/freeware/bin/python2 -t
 
 """This handles actual output from the cli"""
 
--- ./shell.py.orig	2014-06-02 11:02:44.000000000 +0600
+++ ./shell.py	2014-06-02 16:21:27.000000000 +0600
@@ -1,4 +1,4 @@
-#! /usr/bin/python -tt
+#! /opt/freeware/bin/python2 -tt
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
--- ./utils.py.orig	2014-06-02 11:02:44.000000000 +0600
+++ ./utils.py	2014-06-02 16:51:31.000000000 +0600
@@ -1,4 +1,4 @@
-#!/usr/bin/python -t
+#!/opt/freeware/bin/python2 -t
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
--- ./yum-updatesd.py.orig	2014-06-02 11:02:44.000000000 +0600
+++ ./yum-updatesd.py	2014-06-02 18:11:36.000000000 +0600
@@ -1,4 +1,4 @@
-#!/usr/bin/python -tt
+#!/opt/freeware/bin/python2 -tt
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
@@ -53,10 +53,10 @@
 from yum.update_md import UpdateMetadata
 
 # FIXME: is it really sane to use this from here?
-sys.path.append('/usr/share/yum-cli')
+sys.path.append('/opt/freeware/share/yum-cli')
 import callback
 
-config_file = '/etc/yum/yum-updatesd.conf'
+config_file = '/opt/freeware/etc/yum/yum-updatesd.conf'
 initial_directory = os.getcwd()
 
 class UpdateEmitter(object):
@@ -245,7 +245,7 @@
     syslog_facility = Option("DAEMON")
     syslog_level = Option("WARN")
     syslog_ident = Option("yum-updatesd")
-    yum_config = Option("/etc/yum/yum.conf")
+    yum_config = Option("/opt/freeware/etc/yum/yum.conf")
 
 
 class UpdateBuildTransactionThread(threading.Thread):
--- ./yumcommands.py.orig	2014-06-02 11:02:44.000000000 +0600
+++ ./yumcommands.py	2014-06-02 18:33:05.000000000 +0600
@@ -1,4 +1,4 @@
-#!/usr/bin/python -t
+#!/opt/freeware/bin/python2 -t
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
--- ./yummain.py.orig	2014-06-02 11:02:44.000000000 +0600
+++ ./yummain.py	2014-06-02 18:33:29.000000000 +0600
@@ -1,4 +1,4 @@
-#!/usr/bin/python -t
+#!/opt/freeware/bin/python2 -t
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
--- ./yum/Errors.py.orig	2014-06-02 11:02:45.000000000 +0600
+++ ./yum/Errors.py	2014-06-02 16:55:43.000000000 +0600
@@ -1,4 +1,4 @@
-#!/usr/bin/python -tt
+#!/opt/freeware/bin/python2 -tt
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
--- ./yum/callbacks.py.orig	2014-06-02 11:02:45.000000000 +0600
+++ ./yum/callbacks.py	2014-06-02 17:28:51.000000000 +0600
@@ -1,4 +1,4 @@
-#!/usr/bin/python -tt
+#!/opt/freeware/bin/python2 -tt
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
--- ./yum/comps.py.orig	2014-06-02 11:02:45.000000000 +0600
+++ ./yum/comps.py	2014-06-02 17:33:03.000000000 +0600
@@ -1,4 +1,4 @@
-#! /usr/bin/python -tt
+#! /opt/freeware/bin/python2 -tt
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
--- ./yum/config.py.orig	2014-06-02 11:02:45.000000000 +0600
+++ ./yum/config.py	2014-06-02 17:35:05.000000000 +0600
@@ -1,4 +1,4 @@
-#!/usr/bin/python -t
+#!/opt/freeware/bin/python2 -t
 
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -614,10 +614,10 @@
 
     distroverpkg = Option('redhat-release')
     installroot = Option('/')
-    config_file_path = Option('/etc/yum/yum.conf')
+    config_file_path = Option('/opt/freeware/etc/yum/yum.conf')
     plugins = BoolOption(False)
-    pluginpath = ListOption(['/usr/share/yum-plugins', '/usr/lib/yum-plugins'])
-    pluginconfpath = ListOption(['/etc/yum/pluginconf.d'])
+    pluginpath = ListOption(['/opt/freeware/share/yum-plugins', '/opt/freeware/lib/yum-plugins'])
+    pluginconfpath = ListOption(['/opt/freeware/etc/yum/pluginconf.d'])
     gaftonmode = BoolOption(False)
     syslog_ident = Option()
     syslog_facility = Option('LOG_USER')
@@ -637,7 +637,7 @@
 
     keepcache = BoolOption(True)
     logfile = Option('/var/log/yum.log')
-    reposdir = ListOption(['/etc/yum/repos.d', '/etc/yum.repos.d'])
+    reposdir = ListOption(['/opt/freeware/etc/yum/repos.d', '/opt/freeware/etc/yum.repos.d'])
 
     commands = ListOption()
     exclude = ListOption()
@@ -737,7 +737,7 @@
 
     rpmverbosity = Option('info')
 
-    protected_packages = ListOption("yum, glob:/etc/yum/protected.d/*.conf",
+    protected_packages = ListOption("yum, glob:/opt/freeware/etc/yum/protected.d/*.conf",
                                     parse_default=True)
     protected_multilib = BoolOption(True)
     exit_on_lock = BoolOption(False)
@@ -917,7 +917,7 @@
     
     # Read the FS yumvars
     try:
-        dir_fsvars = yumconf.installroot + "/etc/yum/vars/"
+        dir_fsvars = yumconf.installroot + "/opt/freeware/etc/yum/vars/"
         fsvars = os.listdir(dir_fsvars)
     except OSError:
         fsvars = []
@@ -955,7 +955,7 @@
     
     return yumconf
 
-def readVersionGroupsConfig(configfile="/etc/yum/version-groups.conf"):
+def readVersionGroupsConfig(configfile="/opt/freeware/etc/yum/version-groups.conf"):
     parser = ConfigParser()
     confpp_obj = ConfigPreProcessor(configfile)
     try:
@@ -1081,7 +1081,7 @@
     fp.close()
 
 #def main():
-#    mainconf = readMainConfig(readStartupConfig('/etc/yum/yum.conf', '/'))
+#    mainconf = readMainConfig(readStartupConfig('/opt/freeware/etc/yum/yum.conf', '/'))
 #    print mainconf.cachedir
 #
 #if __name__ == '__main__':
--- ./yum/constants.py.orig	2014-06-02 11:02:45.000000000 +0600
+++ ./yum/constants.py	2014-06-02 17:52:54.000000000 +0600
@@ -1,4 +1,4 @@
-#! /usr/bin/python -tt
+#! /opt/freeware/bin/python2 -tt
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
--- ./yum/depsolve.py.orig	2014-06-02 11:02:45.000000000 +0600
+++ ./yum/depsolve.py	2014-06-02 17:52:10.000000000 +0600
@@ -1,4 +1,4 @@
-#!/usr/bin/python -t
+#!/opt/freeware/bin/python2 -t
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
--- ./yum/failover.py.orig	2014-06-02 11:02:45.000000000 +0600
+++ ./yum/failover.py	2014-06-02 17:52:28.000000000 +0600
@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/opt/freeware/bin/python2
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
--- ./yum/history.py.orig	2014-06-02 11:02:45.000000000 +0600
+++ ./yum/history.py	2014-06-02 17:52:54.000000000 +0600
@@ -1,4 +1,4 @@
-#!/usr/bin/python -t
+#!/opt/freeware/bin/python2 -t
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
--- ./yum/i18n.py.orig	2014-06-02 11:02:45.000000000 +0600
+++ ./yum/i18n.py	2014-06-02 17:52:10.000000000 +0600
@@ -1,4 +1,4 @@
-#!/usr/bin/python -tt
+#!/opt/freeware/bin/python2 -tt
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
--- ./yum/logginglevels.py.orig	2014-06-02 11:02:45.000000000 +0600
+++ ./yum/logginglevels.py	2014-06-02 17:52:28.000000000 +0600
@@ -1,4 +1,4 @@
-#! /usr/bin/python -tt
+#! /opt/freeware/bin/python2 -tt
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
--- ./yum/mdparser.py.orig	2014-06-02 11:02:45.000000000 +0600
+++ ./yum/mdparser.py	2014-06-02 17:52:54.000000000 +0600
@@ -1,4 +1,4 @@
-#! /usr/bin/python -tt
+#! /opt/freeware/bin/python2 -tt
 
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
--- ./yum/metalink.py.orig	2014-06-02 11:02:45.000000000 +0600
+++ ./yum/metalink.py	2014-06-02 17:52:10.000000000 +0600
@@ -1,4 +1,4 @@
-#!/usr/bin/python -t
+#!/opt/freeware/bin/python2 -t
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
--- ./yum/packageSack.py.orig	2014-06-02 11:02:45.000000000 +0600
+++ ./yum/packageSack.py	2014-06-02 17:52:54.000000000 +0600
@@ -1,4 +1,4 @@
-#!/usr/bin/python -tt
+#!/opt/freeware/bin/python2 -tt
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
--- ./yum/packages.py.orig	2014-06-02 11:02:45.000000000 +0600
+++ ./yum/packages.py	2014-06-02 17:52:10.000000000 +0600
@@ -1,4 +1,4 @@
-#!/usr/bin/python -tt
+#!/opt/freeware/bin/python2 -tt
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
@@ -1771,7 +1771,7 @@
         results = {} # fn = problem_obj?
 
         # Use prelink_undo_cmd macro?
-        prelink_cmd = "/usr/sbin/prelink"
+        prelink_cmd = "/opt/freeware/sbin/prelink"
         have_prelink = os.path.exists(prelink_cmd)
 
         # determine what checksum algo to use:
--- ./yum/parser.py.orig	2014-06-02 11:02:45.000000000 +0600
+++ ./yum/parser.py	2014-06-02 17:52:28.000000000 +0600
@@ -1,4 +1,4 @@
-#! /usr/bin/python -tt
+#! /opt/freeware/bin/python2 -tt
 import re
 import urlparse
 import urlgrabber
--- ./yum/pgpmsg.py.orig	2014-06-02 11:02:45.000000000 +0600
+++ ./yum/pgpmsg.py	2014-06-02 17:52:54.000000000 +0600
@@ -1,4 +1,4 @@
-#! /usr/bin/python -tt
+#! /opt/freeware/bin/python2 -tt
 ##Copyright (C) 2003,2005,2009  Jens B. Jorgensen <jbj1@ultraemail.net>
 ##
 ##This program is free software; you can redistribute it and/or
--- ./yum/pkgtag_db.py.orig	2014-06-02 11:02:45.000000000 +0600
+++ ./yum/pkgtag_db.py	2014-06-02 17:52:10.000000000 +0600
@@ -1,4 +1,4 @@
-#!/usr/bin/python -tt
+#!/opt/freeware/bin/python2 -tt
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
--- ./yum/plugins.py.orig	2014-06-02 11:02:45.000000000 +0600
+++ ./yum/plugins.py	2014-06-02 17:52:28.000000000 +0600
@@ -1,4 +1,4 @@
-#! /usr/bin/python -tt
+#! /opt/freeware/bin/python2 -tt
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
@@ -133,10 +133,10 @@
             This should be sequnce containing one or more of the TYPE_...
             constants. If None (the default), all plugins will be loaded.
         @param pluginconfpath: A list of paths to look for plugin configuration
-            files. Defaults to "/etc/yum/pluginconf.d".
+            files. Defaults to "/opt/freeware/etc/yum/pluginconf.d".
         '''
         if not pluginconfpath:
-            pluginconfpath = ['/etc/yum/pluginconf.d']
+            pluginconfpath = ['/opt/freeware/etc/yum/pluginconf.d']
 
         self.searchpath = searchpath
         self.pluginconfpath = pluginconfpath
--- ./yum/repoMDObject.py.orig	2014-06-02 11:02:45.000000000 +0600
+++ ./yum/repoMDObject.py	2014-06-02 17:52:54.000000000 +0600
@@ -1,4 +1,4 @@
-#!/usr/bin/python -tt
+#!/opt/freeware/bin/python2 -tt
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
--- ./yum/repos.py.orig	2014-06-02 11:02:45.000000000 +0600
+++ ./yum/repos.py	2014-06-02 17:52:10.000000000 +0600
@@ -1,4 +1,4 @@
-#!/usr/bin/python -tt
+#!/opt/freeware/bin/python2 -tt
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
--- ./yum/rpmsack.py.orig	2014-06-02 11:02:45.000000000 +0600
+++ ./yum/rpmsack.py	2014-06-02 17:52:28.000000000 +0600
@@ -1,4 +1,4 @@
-#!/usr/bin/python -tt
+#!/opt/freeware/bin/python2 -tt
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
--- ./yum/rpmtrans.py.orig	2014-06-02 11:02:45.000000000 +0600
+++ ./yum/rpmtrans.py	2014-06-02 17:52:54.000000000 +0600
@@ -1,4 +1,4 @@
-#!/usr/bin/python -t
+#!/opt/freeware/bin/python2 -t
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
--- ./yum/sqlitesack.py.orig	2014-06-02 11:02:45.000000000 +0600
+++ ./yum/sqlitesack.py	2014-06-02 17:52:10.000000000 +0600
@@ -1,4 +1,4 @@
-#!/usr/bin/python -tt
+#!/opt/freeware/bin/python2 -tt
 
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
--- ./yum/sqlutils.py.orig	2014-06-02 11:02:45.000000000 +0600
+++ ./yum/sqlutils.py	2014-06-02 17:52:28.000000000 +0600
@@ -1,4 +1,4 @@
-#!/usr/bin/python -tt
+#!/opt/freeware/bin/python2 -tt
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of version 2 of the GNU General Public License
 # as published by the Free Software Foundation
@@ -44,7 +44,7 @@
       >>> dhm.strtools.Tokenize("this \"is a test")
       Traceback (most recent call last):
         File "<stdin>", line 1, in ?
-        File "/usr/local/lib/python2.2/site-packages/dhm/strtools.py", line 80, in Tokenize
+        File "/opt/freeware/local/lib/python2.2/site-packages/dhm/strtools.py", line 80, in Tokenize
           raise TokenizeError, "Unexpected end of string in quoted text"
       dhm.strtools.TokenizeError: Unexecpted end of string in quoted text
 
--- ./yum/transactioninfo.py.orig	2014-06-02 11:02:45.000000000 +0600
+++ ./yum/transactioninfo.py	2014-06-02 17:52:54.000000000 +0600
@@ -1,4 +1,4 @@
-#! /usr/bin/python -tt
+#! /opt/freeware/bin/python2 -tt
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
--- ./yum/update_md.py.orig	2014-06-02 11:02:45.000000000 +0600
+++ ./yum/update_md.py	2014-06-02 17:52:10.000000000 +0600
@@ -1,4 +1,4 @@
-#!/usr/bin/python -t
+#!/opt/freeware/bin/python2 -t
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
--- ./yum/yumRepo.py.orig	2014-06-02 11:02:45.000000000 +0600
+++ ./yum/yumRepo.py	2014-06-02 17:52:28.000000000 +0600
@@ -1,4 +1,4 @@
-#! /usr/bin/python -tt
+#! /opt/freeware/bin/python2 -tt
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
--- ./bin/yum-updatesd.py.orig	2014-06-02 14:52:22.000000000 +0600
+++ ./bin/yum-updatesd.py	2014-06-02 14:52:44.000000000 +0600
@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/opt/freeware/bin/python2
 import sys, os
 import optparse
 
@@ -16,7 +16,7 @@
     os.dup2(fd, 2)
     os.close(fd)
 
-sys.path.insert(0, '/usr/share/yum-cli')
+sys.path.insert(0, '/opt/freeware/share/yum-cli')
 try:
     import yumupd
     yumupd.main(options)
--- ./bin/yum.py.orig	2014-06-02 11:02:44.000000000 +0600
+++ ./bin/yum.py	2014-06-02 14:57:06.000000000 +0600
@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/opt/freeware/bin/python2
 import sys
 try:
     import yum
@@ -23,7 +23,7 @@
 """ % (sys.exc_value, sys.version)
     sys.exit(1)
 
-sys.path.insert(0, '/usr/share/yum-cli')
+sys.path.insert(0, '/opt/freeware/share/yum-cli')
 try:
     import yummain
     yummain.user_main(sys.argv[1:], exit_code=True)
--- ./docs/yum.8.orig	2014-06-02 11:02:44.000000000 +0600
+++ ./docs/yum.8	2014-06-02 15:13:15.000000000 +0600
@@ -92,7 +92,7 @@
 the transaction and any matches are removed. If the name is a file, then install works
 like localinstall\&. If the name doesn't match a package, then package
 "provides" are searched (Eg. "_sqlitecache.so()(64bit)") as are
-filelists (Eg. "/usr/bin/yum"). Also note that for filelists, wildcards will
+filelists (Eg. "/opt/freeware/bin/yum"). Also note that for filelists, wildcards will
 match multiple packages\&.
 .IP 
 .IP "\fBupdate\fP"
@@ -289,7 +289,7 @@
 One last special feature of repolist, is that if you are in non-verbose mode
 then yum will ignore any repo errors and output the information it can get
 (Eg. "yum clean all; yum -C repolist" will output something, although the
-package counts/etc. will be zeroed out).
+package counts/opt/freeware/etc. will be zeroed out).
 .IP
 .IP "\fBversion\fP"
 Produces a "version" of the rpmdb, and of the enabled repositories if "all" is
@@ -624,10 +624,10 @@
 1. The plugin module file must be installed in the plugin path as just
 described.
 .LP
-2. The global \fBplugins\fP option in /etc/yum/yum.conf must be set to `1'.
+2. The global \fBplugins\fP option in /opt/freeware/etc/yum/yum.conf must be set to `1'.
 .LP
 3. A configuration file for the plugin must exist in
-/etc/yum/pluginconf.d/<plugin_name>.conf and the \fBenabled\fR setting in this
+/opt/freeware/etc/yum/pluginconf.d/<plugin_name>.conf and the \fBenabled\fR setting in this
 file must set to `1'. The minimal content for such a configuration file is:
 .IP
 [main]
@@ -640,10 +640,10 @@
 .PP
 .SH "FILES"
 .nf
-/etc/yum/yum.conf
-/etc/yum/version-groups.conf
-/etc/yum/repos.d/
-/etc/yum/pluginconf.d/
+/opt/freeware/etc/yum/yum.conf
+/opt/freeware/etc/yum/version-groups.conf
+/opt/freeware/etc/yum/repos.d/
+/opt/freeware/etc/yum/pluginconf.d/
 /var/cache/yum/
 .fi 
 
--- ./docs/yum.conf.5.orig	2014-06-02 11:02:44.000000000 +0600
+++ ./docs/yum.conf.5	2014-06-02 15:17:43.000000000 +0600
@@ -4,10 +4,10 @@
 \fByum.conf\fR \- Configuration file for \fByum(8)\fR.
 .SH "DESCRIPTION"
 .LP
-Yum uses a configuration file at \fB/etc/yum/yum.conf\fR.
+Yum uses a configuration file at \fB/opt/freeware/etc/yum/yum.conf\fR.
 .LP
 Additional configuration files are also read from the directories set by the
-\fBreposdir\fR option (default is `/etc/yum/repos.d').
+\fBreposdir\fR option (default is `/opt/freeware/etc/yum/repos.d').
 See the \fBreposdir\fR option below for further details.
 
 .SH "PARAMETERS"
@@ -42,10 +42,10 @@
 .IP
 \fBreposdir\fR
 A list of directories where yum should look for .repo files which define
-repositories to use. Default is `/etc/yum/repos.d'. Each
+repositories to use. Default is `/opt/freeware/etc/yum/repos.d'. Each
 file in this directory should contain one or more repository sections as
 documented in \fB[repository] options\fR below. These will be merged with the
-repositories defined in /etc/yum/yum.conf to form the complete set of
+repositories defined in /opt/freeware/etc/yum/yum.conf to form the complete set of
 repositories that yum will use.
 
 .IP
@@ -66,9 +66,9 @@
 This is a list of packages that yum should never completely remove. They are
 protected via. Obsoletes as well as user/plugin removals.
 
-The default is: yum glob:/etc/yum/protected.d/*.conf
+The default is: yum glob:/opt/freeware/etc/yum/protected.d/*.conf
 So any packages which should be protected can do so by including a file in 
-/etc/yum/protected.d with their package name in it.
+/opt/freeware/etc/yum/protected.d with their package name in it.
 
 Also if this configuration is set to anything, then yum will protect the
 package corresponding to the running version of the kernel.
@@ -418,12 +418,12 @@
 .IP
 \fBpluginpath \fR
 A list of directories where yum should look for plugin modules. Default is
-`/usr/share/yum-plugins' and `/usr/lib/yum-plugins'.
+`/opt/freeware/share/yum-plugins' and `/opt/freeware/lib/yum-plugins'.
 
 .IP
 \fBpluginconfpath \fR
 A list of directories where yum should look for plugin configuration files.
-Default is `/etc/yum/pluginconf.d'.
+Default is `/opt/freeware/etc/yum/pluginconf.d'.
 
 .IP
 \fBmetadata_expire \fR
@@ -828,8 +828,8 @@
 
 .SH "URL INCLUDE SYNTAX"
 .LP
-The inclusion of external configuration files is supported for /etc/yum/yum.conf
-and the .repo files in the /etc/yum/repos.d directory. To include a URL, use a
+The inclusion of external configuration files is supported for /opt/freeware/etc/yum/yum.conf
+and the .repo files in the /opt/freeware/etc/yum/repos.d directory. To include a URL, use a
 line of the following format:
 
 include=url://to/some/location
@@ -841,7 +841,7 @@
 .SH "GLOB: FOR LIST OPTIONS"
 .LP
 Any of the configurations options which are a list of items can be specfied
-using the glob syntax: \fBglob:/etc/path/somewhere.d/*.conf\fR. This
+using the glob syntax: \fBglob:/opt/freeware/etc/path/somewhere.d/*.conf\fR. This
 will read in all files matching that glob and include all lines in each file
 (excluding comments and blank lines) as items in the list.
 .LP
@@ -882,7 +882,7 @@
 configuration file variable will not be replaced.
 
 .LP
-As of 3.2.28, any file in /etc/yum/vars is turned into a variable named after
+As of 3.2.28, any file in /opt/freeware/etc/yum/vars is turned into a variable named after
 the filename (or overrides any of the above variables).
 
 Note that no warnings/errors are given if the files are unreadable, so creating
@@ -895,11 +895,11 @@
 
 .SH "FILES"
 .nf
-/etc/yum/yum.conf
-/etc/yum/repos.d/
-/etc/yum/pluginconf.d/
-/etc/yum/protected.d
-/etc/yum/vars
+/opt/freeware/etc/yum/yum.conf
+/opt/freeware/etc/yum/repos.d/
+/opt/freeware/etc/yum/pluginconf.d/
+/opt/freeware/etc/yum/protected.d
+/opt/freeware/etc/yum/vars
 
 .SH "SEE ALSO"
 .LP 
--- ./rpmUtils/__init__.py.orig	2014-06-02 11:02:45.000000000 +0600
+++ ./rpmUtils/__init__.py	2014-06-02 15:45:03.000000000 +0600
@@ -1,4 +1,4 @@
-#!/usr/bin/python -tt
+#!/opt/freeware/bin/python2 -tt
 
 
 class RpmUtilsError(Exception):
--- ./rpmUtils/miscutils.py.orig	2014-06-02 11:02:45.000000000 +0600
+++ ./rpmUtils/miscutils.py	2014-06-02 15:47:11.000000000 +0600
@@ -1,4 +1,4 @@
-#!/usr/bin/python -tt
+#!/opt/freeware/bin/python2 -tt
 
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
--- ./rpmUtils/oldUtils.py.orig	2014-06-02 11:02:45.000000000 +0600
+++ ./rpmUtils/oldUtils.py	2014-06-02 15:48:28.000000000 +0600
@@ -1,4 +1,4 @@
-#!/usr/bin/python -tt
+#!/opt/freeware/bin/python2 -tt
 
 import rpm
 import types
--- ./rpmUtils/transaction.py.orig	2014-06-02 11:02:45.000000000 +0600
+++ ./rpmUtils/transaction.py	2014-06-02 16:17:10.000000000 +0600
@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/opt/freeware/bin/python2
 
 #
 # Client code for Update Agent
--- ./rpmUtils/updates.py.orig	2014-06-02 11:02:45.000000000 +0600
+++ ./rpmUtils/updates.py	2014-06-02 16:20:25.000000000 +0600
@@ -1,4 +1,4 @@
-#!/usr/bin/python -tt
+#!/opt/freeware/bin/python2 -tt
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
--- ./test/check-po-yes-no.py.orig	2014-06-02 11:02:45.000000000 +0600
+++ ./test/check-po-yes-no.py	2014-06-02 16:24:38.000000000 +0600
@@ -1,4 +1,4 @@
-#! /usr/bin/python -tt
+#! /opt/freeware/bin/python2 -tt
 
 # This is a simple command to check that "Is this ok [y/N]: " and yes and no
 # have either all been translated or none have been translated.
--- ./test/release.sh.orig	2014-06-02 11:02:45.000000000 +0600
+++ ./test/release.sh	2014-06-02 16:28:42.000000000 +0600
@@ -97,13 +97,13 @@
 utst yum search || true
 
 stst yum provides zzuf
-stst yum provides /usr/bin/zzuf
-stst yum provides /usr/bin/yum
-utst yum provides /usr/share/man/man1/zzuf.1.gz
-utst yum provides '/usr/share/man/man*/zzuf.*.gz'
-stst yum provides '/usr/share/man/man1/zzcat.*.gz'
-utst yum provides '/usr/share/man/man*/zzcat.*.gz'
-utst yum resolvedep /usr/bin/zzcat
+stst yum provides /opt/freeware/bin/zzuf
+stst yum provides /opt/freeware/bin/yum
+utst yum provides /opt/freeware/share/man/man1/zzuf.1.gz
+utst yum provides '/opt/freeware/share/man/man*/zzuf.*.gz'
+stst yum provides '/opt/freeware/share/man/man1/zzcat.*.gz'
+utst yum provides '/opt/freeware/share/man/man*/zzcat.*.gz'
+utst yum resolvedep /opt/freeware/bin/zzcat
 
 
 stst yum deplist yum
--- ./test/rpmdb-cache.py.orig	2014-06-02 11:02:45.000000000 +0600
+++ ./test/rpmdb-cache.py	2014-06-02 16:34:02.000000000 +0600
@@ -1,4 +1,4 @@
-#! /usr/bin/python -tt
+#! /opt/freeware/bin/python2 -tt
 
 import sys
 import yum
--- ./test/simpleobsoletestests.py.orig	2014-06-02 11:02:45.000000000 +0600
+++ ./test/simpleobsoletestests.py	2014-06-02 16:37:36.000000000 +0600
@@ -356,18 +356,18 @@
         # ... traditionally we've included the other dep. _as well_.
         #  The "main" offender has been postfix, which brings in exim.
         pfix1      = FakePackage('postfix',      '1', '1', '0', 'noarch')
-        pfix1.addProvides('/usr/bin/sendmail')
+        pfix1.addProvides('/opt/freeware/bin/sendmail')
         pfix2      = FakePackage('postfix',      '1', '2', '0', 'noarch')
-        pfix2.addProvides('/usr/bin/sendmail')
+        pfix2.addProvides('/opt/freeware/bin/sendmail')
         pnewfix    = FakePackage('postfix-blah', '1', '2', '0', 'noarch')
         pnewfix.addObsoletes('postfix', 'LT', ('0', '1', '2'))
         pnewfix.addRequires('postfix', 'EQ', ('0', '1', '2'))
 
         dep        = FakePackage('foo', '1', '1', '0', 'noarch')
-        dep.addRequires('/usr/bin/sendmail')
+        dep.addRequires('/opt/freeware/bin/sendmail')
 
         exim       = FakePackage('exim', '1', '1', '0', 'noarch')
-        exim.addProvides('/usr/bin/sendmail')
+        exim.addProvides('/opt/freeware/bin/sendmail')
 
         res, msg = self.runOperation(['update', 'postfix'],
                                      [pfix1, dep], [exim, pnewfix, pfix2, dep])
@@ -380,18 +380,18 @@
         # ... traditionally we've included the other dep. _as well_.
         #  The "main" offender has been postfix, which brings in exim.
         dep        = FakePackage('foo', '1', '1', '0', 'noarch')
-        dep.addRequires('/usr/bin/sendmail')
+        dep.addRequires('/opt/freeware/bin/sendmail')
 
         pfix1      = FakePackage('postfix',      '1', '1', '0', 'noarch')
-        pfix1.addProvides('/usr/bin/sendmail')
+        pfix1.addProvides('/opt/freeware/bin/sendmail')
         pfix2      = FakePackage('postfix',      '1', '2', '0', 'noarch')
-        pfix2.addProvides('/usr/bin/sendmail')
+        pfix2.addProvides('/opt/freeware/bin/sendmail')
         pnewfix    = FakePackage('postfix-blah', '1', '2', '0', 'noarch')
         pnewfix.addObsoletes('postfix', 'LT', ('0', '1', '2'))
         pnewfix.addRequires('postfix', 'EQ', ('0', '1', '2'))
 
         exim       = FakePackage('exim', '1', '1', '0', 'noarch')
-        exim.addProvides('/usr/bin/sendmail')
+        exim.addProvides('/opt/freeware/bin/sendmail')
 
         res, msg = self.runOperation(['update', 'postfix'],
                                      [dep, pfix1], [dep, pfix2, pnewfix, exim])
@@ -404,18 +404,18 @@
         # ... traditionally we've included the other dep. _as well_.
         #  The "main" offender has been postfix, which brings in exim.
         dep        = FakePackage('foo', '1', '1', '0', 'noarch')
-        dep.addRequires('/usr/bin/sendmail')
+        dep.addRequires('/opt/freeware/bin/sendmail')
 
         pfix1      = FakePackage('postfix',      '1', '1', '0', 'noarch')
-        pfix1.addProvides('/usr/bin/sendmail')
+        pfix1.addProvides('/opt/freeware/bin/sendmail')
         pfix2      = FakePackage('postfix',      '1', '2', '0', 'noarch')
-        pfix2.addProvides('/usr/bin/sendmail')
+        pfix2.addProvides('/opt/freeware/bin/sendmail')
         pnewfix    = FakePackage('postfix-blah', '1', '2', '0', 'noarch')
         pnewfix.addObsoletes('postfix', 'LT', ('0', '1', '2'))
         pnewfix.addRequires('postfix', 'EQ', ('0', '1', '2'))
 
         exim       = FakePackage('exim', '1', '1', '0', 'noarch')
-        exim.addProvides('/usr/bin/sendmail')
+        exim.addProvides('/opt/freeware/bin/sendmail')
 
         res, msg = self.runOperation(['install', 'postfix-blah'],
                                      [dep, pfix1], [dep, pfix2, pnewfix, exim])
--- ./test/yum-leak-test.py.orig	2014-06-02 11:02:45.000000000 +0600
+++ ./test/yum-leak-test.py	2014-06-02 16:43:52.000000000 +0600
@@ -1,4 +1,4 @@
-#! /usr/bin/python -tt
+#! /opt/freeware/bin/python2 -tt
 
 # Do either:
 # ./yum-leak-test.py
@@ -82,7 +82,7 @@
         yb.conf.assumeyes = True
         return yb
 
-    sys.path.append('/usr/share/yum-cli')
+    sys.path.append('/opt/freeware/share/yum-cli')
     import cli
     yb = _init()
     out_mem(os.getpid())
--- ./test/yum-release-test.sh.orig	2014-06-02 11:02:45.000000000 +0600
+++ ./test/yum-release-test.sh	2014-06-02 16:48:41.000000000 +0600
@@ -53,7 +53,7 @@
 if [ "$USE_LOCAL_YUM_CONF" == 1 ] ; then
   # copy repos into build root to take advance of local mirrors
   echo "Using local yum repos"
-  cp /etc/yum.repos.d/*.repo $WORKDIR/etc/yum.repos.d/
+  cp /opt/freeware/etc/yum.repos.d/*.repo $WORKDIR/etc/yum.repos.d/
 else
   echo "Not using local yum repos"
   yumdownloader --destdir $WORKDIR/tmp fedora-release
@@ -64,7 +64,7 @@
 echo "Using $WORKDIR"
 
 
-if [ ! -d $WORKDIR/usr/bin ]; then
+if [ ! -d $WORKDIR/opt/freeware/bin ]; then
   echo
   echo "yum groupinstall ${DEFAULTGROUPS[@]}"
   "${YUM[@]}" -y groupinstall "${DEFAULTGROUPS[@]}"
--- ./po/pygettext.py.orig	2014-06-02 11:02:45.000000000 +0600
+++ ./po/pygettext.py	2014-06-02 15:43:36.000000000 +0600
@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/opt/freeware/bin/python2
 # Originally written by Barry Warsaw <bwarsaw@python.org>
 #
 # minimally patched to make it even more xgettext compatible 
--- ./etc/0yum.cron.orig	2014-06-02 11:02:44.000000000 +0600
+++ ./etc/0yum.cron	2014-06-02 15:31:51.000000000 +0600
@@ -1,19 +1,19 @@
 #!/bin/bash
 
-# Only run if this flag file is set (by /etc/rc.d/init.d/yum-cron)
+# Only run if this flag file is set (by /opt/freeware/etc/rc.d/init.d/yum-cron)
 if [ ! -f /var/lock/subsys/yum-cron ]; then
   exit 0
 fi
 
-DAILYSCRIPT=/etc/yum/yum-daily.yum
-WEEKLYSCRIPT=/etc/yum/yum-weekly.yum
+DAILYSCRIPT=/opt/freeware/etc/yum/yum-daily.yum
+WEEKLYSCRIPT=/opt/freeware/etc/yum/yum-weekly.yum
 LOCKDIR=/var/lock/yum-cron.lock
 LOCKFILE=$LOCKDIR/pidfile
 TSLOCK=$LOCKDIR/ts.lock
 
 # Grab config settings
-if [ -f /etc/sysconfig/yum-cron ]; then
-  source /etc/sysconfig/yum-cron
+if [ -f /opt/freeware/etc/sysconfig/yum-cron ]; then
+  source /opt/freeware/etc/sysconfig/yum-cron
 fi
 # set default for SYSTEMNAME
 [ -z "$SYSTEMNAME" ]  && SYSTEMNAME=$(hostname) 
@@ -92,20 +92,20 @@
   # First, if this is CLEANDAY, do so
   CLEANDAY=${CLEANDAY:-0}
   if [ ! "${CLEANDAY/$dow/}" == "${CLEANDAY}" ]; then
-      /usr/bin/yum $YUM_PARAMETER -e ${ERROR_LEVEL:-0} -d ${DEBUG_LEVEL:-0} -y shell $WEEKLYSCRIPT
+      /opt/freeware/bin/yum $YUM_PARAMETER -e ${ERROR_LEVEL:-0} -d ${DEBUG_LEVEL:-0} -y shell $WEEKLYSCRIPT
   fi
 
   # Now continue to do the real work
   if [ "$CHECK_ONLY" == "yes" ]; then
     random_wait
     touch $TSLOCK
-    /usr/bin/yum $YUM_PARAMETER -e 0 -d 0 -y check-update 1> /dev/null 2>&1
+    /opt/freeware/bin/yum $YUM_PARAMETER -e 0 -d 0 -y check-update 1> /dev/null 2>&1
     case $? in
       1)   exit 1;;
       100) echo "New updates available for host `/bin/hostname`";
-           /usr/bin/yum $YUM_PARAMETER -e ${ERROR_LEVEL:-0} -d ${DEBUG_LEVEL:-0} -y -C check-update
+           /opt/freeware/bin/yum $YUM_PARAMETER -e ${ERROR_LEVEL:-0} -d ${DEBUG_LEVEL:-0} -y -C check-update
            if [ "$DOWNLOAD_ONLY" == "yes" ]; then
-	       /usr/bin/yum $YUM_PARAMETER -e ${ERROR_LEVEL:-0} -d ${DEBUG_LEVEL:-0} -y --downloadonly update
+	       /opt/freeware/bin/yum $YUM_PARAMETER -e ${ERROR_LEVEL:-0} -d ${DEBUG_LEVEL:-0} -y --downloadonly update
 	       echo "Updates downloaded, use \"yum -C update\" manually to install them."
 	   fi
 	   ;;
@@ -114,18 +114,18 @@
     # Don't run if we can't access the repos
     random_wait
     touch $TSLOCK
-    /usr/bin/yum $YUM_PARAMETER -e 0 -d 0 check-update 2>&-
+    /opt/freeware/bin/yum $YUM_PARAMETER -e 0 -d 0 check-update 2>&-
     case $? in
       1)   exit 1;;
-      100) /usr/bin/yum $YUM_PARAMETER -e ${ERROR_LEVEL:-0} -d ${DEBUG_LEVEL:-0} -y update yum
-           /usr/bin/yum $YUM_PARAMETER -e ${ERROR_LEVEL:-0} -d ${DEBUG_LEVEL:-0} -y shell $DAILYSCRIPT
+      100) /opt/freeware/bin/yum $YUM_PARAMETER -e ${ERROR_LEVEL:-0} -d ${DEBUG_LEVEL:-0} -y update yum
+           /opt/freeware/bin/yum $YUM_PARAMETER -e ${ERROR_LEVEL:-0} -d ${DEBUG_LEVEL:-0} -y shell $DAILYSCRIPT
            ;;
     esac
   else
     random_wait
     touch $TSLOCK
-    /usr/bin/yum $YUM_PARAMETER -e ${ERROR_LEVEL:-0} -d ${DEBUG_LEVEL:-0} -y update yum
-    /usr/bin/yum $YUM_PARAMETER -e ${ERROR_LEVEL:-0} -d ${DEBUG_LEVEL:-0} -y shell $DAILYSCRIPT
+    /opt/freeware/bin/yum $YUM_PARAMETER -e ${ERROR_LEVEL:-0} -d ${DEBUG_LEVEL:-0} -y update yum
+    /opt/freeware/bin/yum $YUM_PARAMETER -e ${ERROR_LEVEL:-0} -d ${DEBUG_LEVEL:-0} -y shell $DAILYSCRIPT
   fi
 } >> $YUMTMP 2>&1
 
--- ./etc/yum-cron.orig	2014-06-02 11:02:44.000000000 +0600
+++ ./etc/yum-cron	2014-06-03 11:56:08.000000000 +0600
@@ -8,13 +8,13 @@
 #
 # description:  Enable daily run of yum, a program updater.
 # processname:  yum-cron
-# config: /etc/yum/yum-daily.yum
+# config: /opt/freeware/etc/yum/yum-daily.yum
 #
 
 # source function library
-. /etc/rc.d/init.d/functions
+. /opt/freeware/etc/rc.d/init.d/functions
 
-test -f /etc/sysconfig/yum-cron && . /etc/sysconfig/yum-cron
+test -f /opt/freeware/etc/sysconfig/yum-cron && . /opt/freeware/etc/sysconfig/yum-cron
 
 lockfile=/var/lock/subsys/yum-cron
 tslock=/var/lock/yum-cron.lock/ts.lock
--- ./etc/yum-updatesd.init.orig	2014-06-02 11:02:44.000000000 +0600
+++ ./etc/yum-updatesd.init	2014-06-03 11:59:28.000000000 +0600
@@ -9,12 +9,12 @@
 # description:  This is a daemon which periodically checks for updates \
 #               and can send notifications via mail, dbus or syslog.
 # processname:  yum-updatesd
-# config: /etc/yum/yum-updatesd.conf
+# config: /opt/freeware/etc/yum/yum-updatesd.conf
 # pidfile: /var/run/yum-updatesd.pid
 #
 
 # source function library
-. /etc/rc.d/init.d/functions
+. /opt/freeware/etc/rc.d/init.d/functions
 
 RETVAL=0
 
--- ./etc/yum.bash.orig	2014-06-02 11:02:44.000000000 +0600
+++ ./etc/yum.bash	2014-06-03 12:00:58.000000000 +0600
@@ -58,7 +58,7 @@
     local val
     [ $1 = 1 ] && val='\(1\|yes\|true\|on\)' || val='\(0\|no\|false\|off\)'
     COMPREPLY+=( $( compgen -W '$( command grep -il "^\s*enabled\s*=\s*$val" \
-        /etc/yum/pluginconf.d/*.conf 2>/dev/null \
+        /opt/freeware/etc/yum/pluginconf.d/*.conf 2>/dev/null \
         | sed -ne "s|^.*/\([^/]\{1,\}\)\.conf$|\1|p" )' -- "$2" ) )
 }
 
--- ./etc/yum.console.orig	2014-06-02 15:34:12.000000000 +0600
+++ ./etc/yum.console	2014-06-02 15:34:30.000000000 +0600
@@ -1,4 +1,4 @@
 USER=root
-PROGRAM=/usr/sbin/yum
+PROGRAM=/opt/freeware/sbin/yum
 GUI=no
 SESSION=true

--- ./yum/__init__.py.orig	2014-06-02 11:02:45.000000000 +0600
+++ ./yum/__init__.py	2014-06-02 17:25:25.000000000 +0600
@@ -1,4 +1,4 @@
-#!/usr/bin/python -tt
+#!/opt/freeware/bin/python2 -tt
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
@@ -103,11 +103,11 @@
 
 class _YumPreBaseConf:
     """This is the configuration interface for the YumBase configuration.
        So if you want to change if plugins are on/off, or debuglevel/etc.
        you tweak it here, and when yb.conf does it's thing ... it happens. """
 
     def __init__(self):
-        self.fn = '/etc/yum/yum.conf'
+        self.fn = '/opt/freeware/etc/yum/yum.conf'
         self.root = '/'
         self.init_plugins = True
         self.plugin_types = (plugins.TYPE_CORE,)
@@ -231,7 +231,7 @@
         self.preconf.init_plugins = False
         self.conf.cache = cache
 
-    def doConfigSetup(self, fn='/etc/yum/yum.conf', root='/', init_plugins=True,
+    def doConfigSetup(self, fn='/opt/freeware/etc/yum/yum.conf', root='/', init_plugins=True,
             plugin_types=(plugins.TYPE_CORE,), optparser=None, debuglevel=None,
             errorlevel=None):
         warnings.warn(_('doConfigSetup() will go away in a future version of Yum.\n'),
@@ -292,10 +292,10 @@
             arch = self.arch.canonarch
 
         # TODO: Remove this block when we no longer support configs outside
-        # of /etc/yum/
-        if fn == '/etc/yum/yum.conf' and not os.path.exists(fn):
+        # of /opt/freeware/etc/yum/
+        if fn == '/opt/freeware/etc/yum/yum.conf' and not os.path.exists(fn):
             # Try the old default
-            fn = '/etc/yum.conf'
+            fn = '/opt/freeware/etc/yum.conf'
 
         startupconf = config.readStartupConfig(fn, root)
         startupconf.arch = arch
@@ -451,7 +451,7 @@
         """read in repositories from config main and .repo files"""
 
         # Read .repo files from directories specified by the reposdir option
-        # (typically /etc/yum/repos.d)
+        # (typically /opt/freeware/etc/yum/repos.d)
         repo_config_age = self.conf.config_file_age
         
         # Get the repos from the main yum.conf file
@@ -650,7 +650,7 @@
         # tools now rely on being able to create an empty sack and then have it
         # auto. re-init when they add some stuff. So we add a bit more "clever"
         # and don't setup the pkgSack to not be None when it's empty. This means
         # we skip excludes/includes/etc. ... but there's no packages, so
         # hopefully that's ok.
         if self._pkgSack is not None and thisrepo is None:
             return self._pkgSack
@@ -3483,7 +3483,7 @@
                         self.logger.critical(_('No Match for argument: %s') % to_unicode(arg))
                     else:
                         # install MTA* == fail, because provides don't do globs
                         # install /usr/kerberos/bin/* == success (and we want
                         #                                all of the pkgs)
                         if mypkgs and not misc.re_glob(arg):
                             mypkgs = self.bestPackagesFromList(mypkgs,
@@ -103,11 +103,11 @@
 class _YumPreBaseConf:
     """This is the configuration interface for the YumBase configuration.
-       So if you want to change if plugins are on/off, or debuglevel/etc.
+       So if you want to change if plugins are on/off, or debuglevel/opt/freeware/etc.
        you tweak it here, and when yb.conf does it's thing ... it happens. """
 
@@ -650,7 +650,7 @@
         # auto. re-init when they add some stuff. So we add a bit more "clever"
         # and don't setup the pkgSack to not be None when it's empty. This means
-        # we skip excludes/includes/etc. ... but there's no packages, so
+        # we skip excludes/includes/opt/freeware/etc. ... but there's no packages, so
         # hopefully that's ok.
         if self._pkgSack is not None and thisrepo is None:
@@ -3483,7 +3483,7 @@
                     else:
                         # install MTA* == fail, because provides don't do globs
-                        # install /usr/kerberos/bin/* == success (and we want
+                        # install /opt/freeware/kerberos/bin/* == success (and we want
                         #                                all of the pkgs)
                         if mypkgs and not misc.re_glob(arg):
--- ./yum/misc.py.orig	2014-06-02 11:02:45.000000000 +0600
+++ ./yum/misc.py	2014-06-02 17:52:28.000000000 +0600
@@ -1,4 +1,4 @@
-#! /usr/bin/python -tt
+#! /opt/freeware/bin/python2 -tt
 """
 Assorted utility functions for yum.
 """
@@ -110,7 +110,7 @@
         positives). Note that this is a superset of re_primary_dirname(). """
     if re_primary_dirname(filename):
         return True
-    if filename == '/usr/lib/sendmail':
+    if filename == '/opt/freeware/lib/sendmail':
         return True
     return False
 
@@ -119,7 +119,7 @@
         that this is a subset of re_primary_filename(). """
     if 'bin/' in dirname:
         return True
-    if dirname.startswith('/etc/'):
+    if dirname.startswith('/opt/freeware/etc/'):
         return True
     return False
 
@@ -858,7 +858,7 @@
     """ Given a seq, split into a list of lists of length max_entries each. """
     ret = []
     num = len(seq)
-    seq = list(seq) # Trying to use a set/etc. here is bad
+    seq = list(seq) # Trying to use a set/opt/freeware/etc. here is bad
     beg = 0
     while num > max_entries:
         end = beg + max_entries
@@ -1131,7 +1131,7 @@
     return decompress(filename, dest=dest, check_timestamps=True,fn_only=cached)
     
 def read_in_items_from_dot_dir(thisglob, line_as_list=True):
     """takes a glob of a dir (like /etc/foo.d/*.foo)
        returns a list of all the lines in all the files matching
        that glob, ignores comments and blank lines,
        optional paramater 'line_as_list tells whether to
@@ -1131,7 +1131,7 @@
     
 def read_in_items_from_dot_dir(thisglob, line_as_list=True):
-    """takes a glob of a dir (like /etc/foo.d/*.foo)
+    """takes a glob of a dir (like /opt/freeware/etc/foo.d/*.foo)
        returns a list of all the lines in all the files matching
        that glob, ignores comments and blank lines,
--- ./test/skipbroken-tests.py.orig	2014-06-02 11:02:45.000000000 +0600
+++ ./test/skipbroken-tests.py	2014-06-02 16:39:28.000000000 +0600
@@ -653,21 +653,21 @@
     def testMissingfileReqIptabes(self):    
         '''
         RHBZ #555528
-        iptables-0:1.4.5-1.fc12.i686 provides /usr/lib/libxtables.so.2
+        iptables-0:1.4.5-1.fc12.i686 provides /opt/freeware/lib/libxtables.so.2
         is updated to
-        iptables-0:1.4.6-1.fc13.i686 provides /usr/lib/libxtables.so.4
-        so libguestfs-1:1.0.81-1.fc13.i686 that requires /usr/lib/libxtables.so.2
-        breaks because /usr/lib/libxtables.so.2 no longer exists.
+        iptables-0:1.4.6-1.fc13.i686 provides /opt/freeware/lib/libxtables.so.4
+        so libguestfs-1:1.0.81-1.fc13.i686 that requires /opt/freeware/lib/libxtables.so.2
+        breaks because /opt/freeware/lib/libxtables.so.2 no longer exists.
         
         It fails in real life but not in the testcase :(
         
         '''
         i1 = self.instPackage('iptables','1.4.5', arch='x86_64')
-        i1.addFile("/usr/lib64/libxtables.so.2")
+        i1.addFile("/opt/freeware/lib64/libxtables.so.2")
         i2 = self.instPackage('libguestfs','1.0.81', arch='x86_64')
-        i2.addRequires("/usr/lib64/libxtables.so.2")
+        i2.addRequires("/opt/freeware/lib64/libxtables.so.2")
         u1 = self.repoPackage('iptables','1.4.6', arch='x86_64')
-        u1.addFile("/usr/lib64/libxtables.so.4")
+        u1.addFile("/opt/freeware/lib64/libxtables.so.4")
         self.tsInfo.addUpdate(u1, oldpo=i1)
         self.assertEquals('empty', *self.resolveCode(skip=True))
         self.assertResult([i1,i2])
@@ -742,12 +742,12 @@
         members = []
         # Installed package conflicts with ux1
         ix0 = self.instString('1:libguestfs-1.6.0-1.fc14.1.i686')
-        ix0.addRequires('/usr/lib/.libssl.so.1.0.0a.hmac')
+        ix0.addRequires('/opt/freeware/lib/.libssl.so.1.0.0a.hmac')
         members.append(ix0)
         ix1 = self.instString('openssl-1.0.0a-2.fc14.i686')
-        ix1.addFile("/usr/lib/.libssl.so.1.0.0a.hmac")
+        ix1.addFile("/opt/freeware/lib/.libssl.so.1.0.0a.hmac")
         ux1 = self.repoString('openssl-1.0.0b-1.fc14.i686')
-        ux1.addFile("/usr/lib/.libssl.so.1.0.0b.hmac")
+        ux1.addFile("/opt/freeware/lib/.libssl.so.1.0.0b.hmac")
         self.tsInfo.addUpdate(ux1, oldpo=ix1)
         members.append(ix1)
         self.assertEquals('empty', *self.resolveCode(skip=True))
@@ -762,12 +762,12 @@
         members = []
         # Installed package conflicts with ux1
         ix0 = self.instString('1:libguestfs-1.6.0-1.fc14.1.i686')
-        ix0.addRequires('/usr/lib/.libssl.so.1.0.0a.hmac')
+        ix0.addRequires('/opt/freeware/lib/.libssl.so.1.0.0a.hmac')
         members.append(ix0)
         ix1 = self.instString('openssl-1.0.0a-2.fc14.i686')
-        ix1.addFile("/usr/lib/.libssl.so.1.0.0a.hmac")
+        ix1.addFile("/opt/freeware/lib/.libssl.so.1.0.0a.hmac")
         ux1 = self.repoString('openssl-1.0.0b-1.fc14.i686')
-        ux1.addFile("/usr/lib/.libssl.so.1.0.0b.hmac")
+        ux1.addFile("/opt/freeware/lib/.libssl.so.1.0.0b.hmac")
         self.tsInfo.addUpdate(ux1, oldpo=ix1)
         members.append(ix1)
         # this is just junk to make the transaction big
@@ -794,12 +794,12 @@
         members = []
         # Installed package conflicts with ux1
         ix0 = self.instString('1:libguestfs-1.6.0-1.fc14.1.i686')
-        ix0.addRequires('/usr/lib/.libssl.so.1.0.0a.hmac')
+        ix0.addRequires('/opt/freeware/lib/.libssl.so.1.0.0a.hmac')
         members.append(ix0)
         ix1 = self.instString('openssl-1.0.0a-2.fc14.i686')
-        ix1.addFile("/usr/lib/.libssl.so.1.0.0a.hmac")
+        ix1.addFile("/opt/freeware/lib/.libssl.so.1.0.0a.hmac")
         ux1 = self.repoString('openssl-1.0.0b-1.fc14.i686')
-        ux1.addFile("/usr/lib/.libssl.so.1.0.0b.hmac")
+        ux1.addFile("/opt/freeware/lib/.libssl.so.1.0.0b.hmac")
         self.tsInfo.addUpdate(ux1, oldpo=ix1)
         members.append(ix1)
         # this is just junk to make the transaction big